@@ -14,7 +14,7 @@ Common options:
 
 use serde::Deserialize;
 
-use crate::{config::Config, util, CliResult};
+use crate::{CliResult, config::Config, util};
 
 #[derive(Deserialize)]
 struct Args {
