@@ -329,8 +329,10 @@ fn check_stats_cache(args: &Args) -> Result<bool, CliError> {
         flag_enum_threshold:  0,
         flag_ignore_case:     false,
         flag_strict_dates:    false,
+        flag_strict_formats:  false,
         flag_pattern_columns: SelectColumns::parse("")?,
         flag_stdout:          false,
+        flag_output:          None,
     };
 
     // Set stats config for right file using same args
