@@ -51,6 +51,12 @@ as it may contain special characters like ! and $:
   $ qsv excel --range 'Sheet2!C3:T25' input.xlsx
   $ qsv excel --range 'Sheet2!$C$3:$T$25' input.xlsx
 
+Export the cell C3 in the first sheet:
+  $ qsv excel --cell C3 input.xlsx
+
+Export a single cell from a specific sheet:
+  $ qsv excel --cell 'Sheet2!C3' input.xlsx
+
 Export metadata for all sheets in CSV format:
   $ qsv excel --metadata csv input.xlsx
   $ qsv excel --metadata c input.xlsx
@@ -127,6 +133,9 @@ Excel options:
                                extract to the CSV. If the specified range contains the required sheet,
                                the --sheet option is ignored.
                                If the range is not found, qsv will exit with an error.
+    --cell <cell>              A single cell reference - like C3 or 'Sheet1!C3' to extract.
+                               This is a convenience option equivalent to --range C3:C3.
+                               If both --cell and --range are specified, --cell takes precedence.
 
     --error-format <format>    The format to use when formatting error cells.
                                There are 3 formats:
@@ -184,6 +193,7 @@ struct Args {
     flag_error_format:   String,
     flag_table:          Option<String>,
     flag_range:          Option<String>,
+    flag_cell:           Option<String>,
     flag_flexible:       bool,
     flag_trim:           bool,
     flag_output:         Option<String>,
@@ -403,7 +413,23 @@ fn get_requested_range(
 }
 
 pub fn run(argv: &[&str]) -> CliResult<()> {
-    let args: Args = util::get_args(USAGE, argv)?;
+    let mut args: Args = util::get_args(USAGE, argv)?;
+
+    // Convert --cell to --range format if --cell is specified
+    if let Some(ref cell_ref) = args.flag_cell {
+        // If both --cell and --range are specified, --cell takes precedence
+        let range_str = if cell_ref.contains('!') {
+            // Sheet-qualified cell reference: Sheet2!C3 -> Sheet2!C3:C3
+            format!(
+                "{cell_ref}:{}",
+                cell_ref.split('!').next_back().unwrap_or(cell_ref)
+            )
+        } else {
+            // Simple cell reference: C3 -> C3:C3
+            format!("{cell_ref}:{cell_ref}")
+        };
+        args.flag_range = Some(range_str);
+    }
 
     // accept spreadsheets from stdin
     let tmpdir = tempfile::tempdir()?;
@@ -1018,7 +1044,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
 
             let mut cell_formula;
             let mut itoa_buf = itoa::Buffer::new();
-            let mut ryu_buf = ryu::Buffer::new();
+            let mut zmij_buf = zmij::Buffer::new();
 
             for (row_idx, row) in chunk {
                 for (col_idx, cell) in row.iter().enumerate() {
@@ -1027,7 +1053,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                         Data::String(s) => record.push_field(s),
                         Data::Int(i) => record.push_field(itoa_buf.format(*i)),
                         Data::Float(float_val) => {
-                            // push the ryu-formatted float value if its
+                            // push the zmij-formatted float value if its
                             // not an integer or the candidate
                             // integer is too big or too small to be an i64
                             #[allow(clippy::cast_precision_loss)]
@@ -1035,9 +1061,9 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                                 || *float_val > i64::MAX as f64
                                 || *float_val < i64::MIN as f64
                             {
-                                record.push_field(ryu_buf.format_finite(*float_val));
+                                record.push_field(zmij_buf.format_finite(*float_val));
                             } else {
-                                // its an i64 integer. We can't use ryu to format it, because it
+                                // its an i64 integer. We can't use zmij to format it, because it
                                 // will be formatted as a float (have a ".0"). So we use itoa.
                                 record.push_field(itoa_buf.format(*float_val as i64));
                             }
