@@ -3,19 +3,19 @@ Convert between various spatial formats and CSV/SVG including GeoJSON, SHP, and
 
 For example to convert a GeoJSON file into CSV data:
 
-qsv geoconvert file.geojson geojson csv
+  $ qsv geoconvert file.geojson geojson csv
 
 To use stdin as input instead of a file path, use a dash "-":
 
-qsv prompt -m "Choose a GeoJSON file" -F geojson | qsv geoconvert - geojson csv
+  $ qsv prompt -m "Choose a GeoJSON file" -F geojson | qsv geoconvert - geojson csv
 
 To convert a CSV file into GeoJSON data, specify the WKT geometry column with the --geometry flag:
 
-qsv geoconvert file.csv csv geojson --geometry geometry
+  $ qsv geoconvert file.csv csv geojson --geometry geometry
 
 Alternatively specify the latitude and longitude columns with the --latitude and --longitude flags:
 
-qsv geoconvert file.csv csv geojson --latitude lat --longitude lon
+  $ qsv geoconvert file.csv csv geojson --latitude lat --longitude lon
 
 Usage:
     qsv geoconvert [options] (<input>) (<input-format>) (<output-format>)
@@ -39,7 +39,7 @@ geoconvert options:
 
     -l, --max-length <length>    The maximum column length when the output format is CSV.
                                  Oftentimes, the geometry column is too long to fit in a
-                                 CSV file, causing other tools like Python & PostgreSQL to fail. 
+                                 CSV file, causing other tools like Python & PostgreSQL to fail.
                                  If a column is too long, it will be truncated to the specified
                                  length and an ellipsis ("...") will be appended.
 
