@@ -519,23 +519,12 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                     asof_options.tolerance_str = Some(tolerance.into());
                 }
             }
-            if args.flag_left_by.is_some() {
-                asof_options.left_by = Some(
-                    args.flag_left_by
-                        .unwrap()
-                        .split(',')
-                        .map(PlSmallStr::from_str)
-                        .collect(),
-                );
+            if let Some(left_by) = args.flag_left_by {
+                asof_options.left_by = Some(left_by.split(',').map(PlSmallStr::from_str).collect());
             }
-            if args.flag_right_by.is_some() {
-                asof_options.right_by = Some(
-                    args.flag_right_by
-                        .unwrap()
-                        .split(',')
-                        .map(PlSmallStr::from_str)
-                        .collect(),
-                );
+            if let Some(right_by) = args.flag_right_by {
+                asof_options.right_by =
+                    Some(right_by.split(',').map(PlSmallStr::from_str).collect());
             }
             join.run(
                 JoinType::AsOf(Box::new(asof_options)),
@@ -911,6 +900,7 @@ impl Args {
                 flag_enum_threshold:  0,
                 flag_ignore_case:     false,
                 flag_strict_dates:    false,
+                flag_strict_formats:  false,
                 flag_pattern_columns: crate::select::SelectColumns::parse("").unwrap(),
                 flag_dates_whitelist: String::new(),
                 flag_prefer_dmy:      false,
@@ -922,6 +912,7 @@ impl Args {
                 flag_delimiter:       args.flag_delimiter,
                 arg_input:            Some(input_path.to_string_lossy().into_owned()),
                 flag_memcheck:        false,
+                flag_output:          None,
             };
 
             let (csv_fields, csv_stats, _) =
@@ -1009,7 +1000,10 @@ impl Args {
 
             // First, check if the pschema.json file exists and is newer or created at the same time
             // as the table file
-            let schema_file = input_path.canonicalize()?.with_extension("pschema.json");
+            let schema_file = PathBuf::from(format!(
+                "{}.pschema.json",
+                input_path.canonicalize()?.display()
+            ));
             let mut valid_schema_exists = schema_file.exists()
                 && schema_file.metadata()?.modified()? >= input_path.metadata()?.modified()?;
 
@@ -1157,7 +1151,10 @@ impl Args {
         if create_left_schema {
             let schema = left_lf.collect_schema()?;
             let schema_json = simd_json::to_string_pretty(&schema)?;
-            let schema_file = input1_path.canonicalize()?.with_extension("pschema.json");
+            let schema_file = PathBuf::from(format!(
+                "{}.pschema.json",
+                input1_path.canonicalize()?.display()
+            ));
             let mut file = BufWriter::new(File::create(&schema_file)?);
             file.write_all(schema_json.as_bytes())?;
             file.flush()?;
@@ -1191,7 +1188,10 @@ impl Args {
         if create_right_schema {
             let schema = right_lf.collect_schema()?;
             let schema_json = simd_json::to_string_pretty(&schema)?;
-            let schema_file = input2_path.canonicalize()?.with_extension("pschema.json");
+            let schema_file = PathBuf::from(format!(
+                "{}.pschema.json",
+                input2_path.canonicalize()?.display()
+            ));
             let mut file = BufWriter::new(File::create(&schema_file)?);
             file.write_all(schema_json.as_bytes())?;
             file.flush()?;
