@@ -86,8 +86,12 @@ lens options:
                                    For convenience, the first character can be used as a shortcut:
                                      qsv lens -W w data.csv // wrap at word boundaries
                                    [default: disabled]
+  -A, --auto-reload                Automatically reload the data when the file changes.
+  --no-streaming-stdin             Disable streaming stdin (load entire input before displaying)
+                                   NOTE: This option only applies to stdin input.
+  
 
-  -P. --prompt <prompt>            Set a custom prompt in the status bar. Normally paired w/ --echo-column:
+  -P, --prompt <prompt>            Set a custom prompt in the status bar. Normally paired w/ --echo-column:
                                      qsv lens --prompt 'Select City:' --echo-column 'City'
                                    Supports ANSI escape codes for colored or styled text. When using
                                    escape codes, ensure it's properly escaped. For example, in bash/zsh,
@@ -118,39 +122,49 @@ use crate::{CliError, CliResult, config::Config, util};
 
 #[derive(Deserialize)]
 struct Args {
-    arg_input:           Option<String>,
-    flag_delimiter:      Option<String>,
-    flag_tab_separated:  bool,
-    flag_no_headers:     bool,
-    flag_columns:        Option<String>,
-    flag_filter:         Option<String>,
-    flag_find:           Option<String>,
-    flag_ignore_case:    bool,
-    flag_freeze_columns: Option<u64>,
-    flag_monochrome:     bool,
-    flag_prompt:         Option<String>,
-    flag_echo_column:    Option<String>,
-    flag_wrap_mode:      String,
-    flag_debug:          bool,
+    arg_input:               Option<String>,
+    flag_delimiter:          Option<String>,
+    flag_tab_separated:      bool,
+    flag_no_headers:         bool,
+    flag_columns:            Option<String>,
+    flag_filter:             Option<String>,
+    flag_find:               Option<String>,
+    flag_ignore_case:        bool,
+    flag_freeze_columns:     Option<u64>,
+    flag_monochrome:         bool,
+    flag_prompt:             Option<String>,
+    flag_echo_column:        Option<String>,
+    flag_wrap_mode:          String,
+    flag_auto_reload:        bool,
+    flag_debug:              bool,
+    flag_no_streaming_stdin: bool,
 }
 
 pub fn run(argv: &[&str]) -> CliResult<()> {
     let args: Args = util::get_args(USAGE, argv)?;
 
-    // Process input file
-    // support stdin and auto-decompress snappy file
-    // stdin/decompressed file is written to a temporary file in tmpdir
-    // which is automatically deleted after the command finishes
+    if args.flag_no_streaming_stdin && args.arg_input.is_some() {
+        return fail_incorrectusage_clierror!("--streaming-stdin only applies to stdin input.");
+    }
+
     let tmpdir = tempfile::tempdir()?;
-    let work_input = util::process_input(
-        vec![PathBuf::from(
-            // if no input file is specified, read from stdin "-"
-            args.arg_input.unwrap_or_else(|| "-".to_string()),
-        )],
-        &tmpdir,
-        "",
-    )?;
-    let input = work_input[0].to_string_lossy().to_string();
+    let input = if !args.flag_no_streaming_stdin && args.arg_input.is_none() {
+        "-".to_string()
+    } else {
+        // Process input file
+        // support stdin and auto-decompress snappy file
+        // stdin/decompressed file is written to a temporary file in tmpdir
+        // which is automatically deleted after the command finishes
+        let work_input = util::process_input(
+            vec![PathBuf::from(
+                // if no input file is specified, read from stdin "-"
+                args.arg_input.clone().unwrap_or_else(|| "-".to_string()),
+            )],
+            &tmpdir,
+            "",
+        )?;
+        work_input[0].to_string_lossy().to_string()
+    };
 
     // If the prompt starts with "file:", it's interpreted as a filepath
     // from which to load the prompt, e.g.
@@ -213,6 +227,8 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         color_columns: !monochrome,
         prompt,
         wrap_mode,
+        auto_reload: args.flag_auto_reload,
+        no_streaming_stdin: args.flag_no_streaming_stdin,
     };
 
     let out = run_csvlens_with_options(options)
