@@ -70,7 +70,7 @@ use std::{
     fs::File,
     io,
     io::{BufReader, Read, Write},
-    path::Path,
+    path::{Path, PathBuf},
     sync::OnceLock,
 };
 
@@ -130,12 +130,13 @@ fn calculate_pivot_metadata(
     args: &Args,
     on_cols: &[String],
     value_cols: Option<&Vec<String>>,
-) -> CliResult<Option<PivotMetadata>> {
+) -> Option<PivotMetadata> {
     // Get stats records
     let schema_args = util::SchemaArgs {
         flag_enum_threshold:  0,
         flag_ignore_case:     false,
         flag_strict_dates:    false,
+        flag_strict_formats:  false,
         flag_pattern_columns: crate::select::SelectColumns::parse("").unwrap(),
         flag_dates_whitelist: String::new(),
         flag_prefer_dmy:      false,
@@ -147,6 +148,7 @@ fn calculate_pivot_metadata(
         flag_delimiter:       args.flag_delimiter,
         arg_input:            Some(args.arg_input.clone()),
         flag_memcheck:        false,
+        flag_output:          None,
     };
 
     #[allow(unused_variables)]
@@ -156,7 +158,7 @@ fn calculate_pivot_metadata(
     });
 
     if csv_stats.is_empty() {
-        return Ok(None);
+        return None;
     }
 
     // Get cardinalities for pivot columns
@@ -181,10 +183,10 @@ fn calculate_pivot_metadata(
     };
     let estimated_columns = total_new_columns.saturating_mul(value_cols_count);
 
-    Ok(Some(PivotMetadata {
+    Some(PivotMetadata {
         estimated_columns,
         on_col_cardinalities,
-    }))
+    })
 }
 
 /// Validate pivot operation using metadata
@@ -241,6 +243,7 @@ fn suggest_agg_function(
         flag_enum_threshold:  0,
         flag_ignore_case:     false,
         flag_strict_dates:    false,
+        flag_strict_formats:  false,
         flag_pattern_columns: crate::select::SelectColumns::parse("").unwrap(),
         flag_dates_whitelist: String::new(),
         flag_prefer_dmy:      false,
@@ -252,6 +255,7 @@ fn suggest_agg_function(
         flag_delimiter:       args.flag_delimiter,
         arg_input:            Some(args.arg_input.clone()),
         flag_memcheck:        false,
+        flag_output:          None,
     };
 
     let (csv_fields, csv_stats, dataset_stats) = STATS_RECORDS.get_or_init(|| {
@@ -566,7 +570,10 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     // check if the pschema.json file exists and is newer or created at the same time
     // as the table file
     let input_path = Path::new(&args.arg_input);
-    let schema_file = input_path.canonicalize()?.with_extension("pschema.json");
+    let schema_file = PathBuf::from(format!(
+        "{}.pschema.json",
+        input_path.canonicalize()?.display()
+    ));
     let valid_schema_exists = schema_file.exists()
         && schema_file.metadata()?.modified()? >= input_path.metadata()?.modified()?;
 
@@ -637,7 +644,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     if args.flag_validate {
         // Validate the operation - need to collect to get metadata
         let df_for_validation = lf.clone().collect()?;
-        if let Some(metadata) = calculate_pivot_metadata(&args, &on_cols, Some(&actual_value_cols))?
+        if let Some(metadata) = calculate_pivot_metadata(&args, &on_cols, Some(&actual_value_cols))
         {
             validate_pivot_operation(&metadata)?;
         }
