@@ -288,6 +288,7 @@ use std::{
 
 use polars::{
     io::avro::{AvroWriter, Compression as AvroCompression},
+    polars_utils::compression::{GzipLevel, ZstdLevel},
     prelude::*,
     sql::SQLContext,
 };
@@ -438,6 +439,7 @@ impl OutputMode {
                         }
                     };
 
+                    #[allow(clippy::decimal_bitwise_operands)]
                     ParquetWriter::new(&mut w)
                         .with_row_group_size(Some(768 ^ 2))
                         .with_statistics(statistics_options)
@@ -488,7 +490,7 @@ impl OutputMode {
         match execute_inner() {
             Ok(()) => Ok(df.shape()),
             Err(e) => {
-                fail_clierror!("Failed to execute query: {query}: {e}")
+                fail_clierror!("Failed to execute query:\n{query}\n\nERROR: {e}")
             },
         }
     }
@@ -683,9 +685,10 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     // if there is only one input file, check if the pschema.json file exists and is newer or
     // created at the same time as the table file, if so, we can enable the cache schema flag
     if args.arg_input.len() == 1 {
-        let schema_file = args.arg_input[0]
-            .canonicalize()?
-            .with_extension("pschema.json");
+        let schema_file = PathBuf::from(format!(
+            "{}.pschema.json",
+            args.arg_input[0].canonicalize()?.display()
+        ));
         if schema_file.exists()
             && schema_file.metadata()?.modified()? >= args.arg_input[0].metadata()?.modified()?
         {
@@ -737,7 +740,8 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             // we build the lazyframe, accounting for the --cache-schema flag
             let mut create_schema = cache_schemas;
 
-            let schema_file = table.canonicalize()?.with_extension("pschema.json");
+            let schema_file =
+                PathBuf::from(format!("{}.pschema.json", table.canonicalize()?.display()));
 
             // check if the pschema.json file exists and is newer or created at the same time
             // as the table file
@@ -878,7 +882,8 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                 let schema = lf.collect_schema()?;
                 let schema_json = simd_json::to_string_pretty(&schema)?;
 
-                let schema_file = table.canonicalize()?.with_extension("pschema.json");
+                let schema_file =
+                    PathBuf::from(format!("{}.pschema.json", table.canonicalize()?.display()));
                 let mut file = BufWriter::new(File::create(&schema_file)?);
                 file.write_all(schema_json.as_bytes())?;
                 file.flush()?;
@@ -902,9 +907,9 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
 
         // remove comments from the SQL script
         // we only support single-line comments in SQL scripts
-        // i.e. comments that start with "--" and end at the end of the line
-        // so the regex is performant and simple
-        let comment_regex = Regex::new(r"^--.*$")?;
+        // i.e. comments that start with "--" (optionally preceded by whitespace) and end at the end
+        // of the line so the regex is performant and simple
+        let comment_regex = Regex::new(r"^\s*--.*$")?;
         let sql_script = comment_regex.replace_all(&sql_script, "");
         sql_script
             .split(';')
