@@ -211,7 +211,7 @@ impl Config {
                 };
                 #[cfg(not(feature = "polars"))]
                 let special_format = SpecialFormat::Unknown;
-                let (file_extension, delim, snappy) = if special_format == SpecialFormat::Unknown {
+                let (delim, snappy) = if special_format == SpecialFormat::Unknown {
                     let (file_extension, delim, snappy) =
                         get_delim_by_extension(&path, default_delim);
                     format_error = if skip_format_check {
@@ -226,21 +226,23 @@ impl Config {
                             )),
                         }
                     };
-                    (file_extension, delim, snappy)
+                    (delim, snappy)
                 } else {
                     match util::convert_special_format(&path, special_format, default_delim) {
                         Ok(temp_path) => {
                             path.clone_from(&temp_path);
                             sniff = false;
-                            get_delim_by_extension(&temp_path, default_delim)
+                            let (_, delim, snappy) =
+                                get_delim_by_extension(&temp_path, default_delim);
+                            (delim, snappy)
                         },
                         Err(e) => {
                             format_error = Some(format!("Failed to convert special format: {e}"));
-                            ("DUMMY".to_string(), default_delim, false)
+                            (default_delim, false)
                         },
                     }
                 };
-                (Some(path), delim, snappy || file_extension.ends_with("sz"))
+                (Some(path), delim, snappy)
             },
         };
         let comment: Option<u8> = match env::var("QSV_COMMENT_CHAR") {
@@ -676,8 +678,31 @@ impl Config {
             Some(ref p) => match fs::File::open(p) {
                 Ok(x) => {
                     if self.snappy {
-                        info!("decoding snappy-compressed file: {}", p.display());
-                        Box::new(snap::read::FrameDecoder::new(x))
+                        // Validate that the file is actually a snappy-compressed file
+                        // before attempting decompression. This prevents "corrupt input" errors
+                        // when a plain CSV file is incorrectly detected as snappy.
+                        match util::is_valid_snappy_file(p) {
+                            Ok(true) => {
+                                info!("decoding snappy-compressed file: {}", p.display());
+                                Box::new(snap::read::FrameDecoder::new(x))
+                            },
+                            Ok(false) => {
+                                warn!(
+                                    "File {} has .sz extension but is not a valid Snappy file. \
+                                     Reading as plain file.",
+                                    p.display()
+                                );
+                                Box::new(x)
+                            },
+                            Err(e) => {
+                                warn!(
+                                    "Failed to validate Snappy file {}: {}. Reading as plain file.",
+                                    p.display(),
+                                    e
+                                );
+                                Box::new(x)
+                            },
+                        }
                     } else {
                         Box::new(x)
                     }
@@ -741,22 +766,27 @@ impl Config {
     }
 }
 
-/// Determines the delimiter and compression status based on the file extension.
+/// Checks if a file path has a Snappy compression extension (.sz).
 ///
 /// # Arguments
 ///
 /// * `path` - A reference to the `Path` of the file.
-/// * `default_delim` - The default delimiter to use if not determined by extension.
 ///
 /// # Returns
 ///
-/// A tuple containing:
-/// * `String` - The lowercase file extension.
-/// * `u8` - The determined delimiter.
-/// * `bool` - Whether the file is Snappy-compressed.
+/// `true` if the file has a `.sz` extension (case-insensitive), `false` otherwise.
 ///
 /// # Details
 ///
+/// This function uses Rust's `Path::extension()` method which properly handles
+/// multiple extensions (e.g., `file.csv.sz` → `Some("sz")`). It performs
+/// case-insensitive comparison for robustness.
+#[inline]
+pub fn is_snappy_extension(path: &Path) -> bool {
+    path.extension()
+        .is_some_and(|ext| ext.eq_ignore_ascii_case("sz"))
+}
+
 /// This function examines the file extension to determine:
 /// 1. The appropriate delimiter (tab for .tsv/.tab, semicolon for .ssv, comma for .csv).
 /// 2. Whether the file is Snappy-compressed (indicated by a .sz extension).
@@ -764,24 +794,21 @@ impl Config {
 ///
 /// If the file extension doesn't match known types, it returns the default delimiter.
 pub fn get_delim_by_extension(path: &Path, default_delim: u8) -> (String, u8, bool) {
-    let path_str = path.to_str().unwrap_or_default().to_ascii_lowercase();
-
-    // we already lowercased the path_str, so allow this false positive lint
-    #[allow(clippy::case_sensitive_file_extension_comparisons)]
-    let snappy = path_str.ends_with(".sz");
+    let snappy = is_snappy_extension(path);
 
     // Get the extension before .sz if it's a snappy file, otherwise get the normal extension
     let file_extension = if snappy {
-        path_str
-            .strip_suffix(".sz")
-            .and_then(|s| s.split('.').next_back())
+        // For snappy files like file.csv.sz, we need to get "csv"
+        // We can do this by getting the file stem, then checking its extension
+        path.file_stem()
+            .and_then(|stem| Path::new(stem).extension())
+            .and_then(|ext| ext.to_str())
             .unwrap_or("")
-            .to_string()
+            .to_ascii_lowercase()
     } else {
         path.extension()
-            .unwrap_or_default()
-            .to_str()
-            .unwrap()
+            .and_then(|ext| ext.to_str())
+            .unwrap_or("")
             .to_ascii_lowercase()
     };
 
@@ -943,4 +970,59 @@ mod tests {
         assert_eq!(delim, default_delim);
         assert!(!snappy);
     }
+
+    #[test]
+    fn test_is_snappy_extension_lowercase() {
+        assert!(is_snappy_extension(Path::new("file.csv.sz")));
+        assert!(is_snappy_extension(Path::new("file.sz")));
+        assert!(is_snappy_extension(Path::new("file.tsv.sz")));
+    }
+
+    #[test]
+    fn test_is_snappy_extension_uppercase() {
+        assert!(is_snappy_extension(Path::new("file.csv.SZ")));
+        assert!(is_snappy_extension(Path::new("file.SZ")));
+    }
+
+    #[test]
+    fn test_is_snappy_extension_mixed_case() {
+        assert!(is_snappy_extension(Path::new("file.csv.Sz")));
+        assert!(is_snappy_extension(Path::new("file.sZ")));
+    }
+
+    #[test]
+    fn test_is_snappy_extension_not_snappy() {
+        assert!(!is_snappy_extension(Path::new("file.csv")));
+        assert!(!is_snappy_extension(Path::new("file.gz")));
+        assert!(!is_snappy_extension(Path::new("file")));
+        assert!(!is_snappy_extension(Path::new("file.sz.backup")));
+        // Test that extensions ending with "sz" but not exactly "sz" don't trigger detection
+        assert!(!is_snappy_extension(Path::new("file.esz")));
+        assert!(!is_snappy_extension(Path::new("file.KYpPcb8esz")));
+        assert!(!is_snappy_extension(Path::new("data.esz")));
+    }
+
+    #[test]
+    fn test_snappy_ssv_extension() {
+        let path = PathBuf::from("test.ssv.sz");
+        let (ext, delim, snappy) = get_delim_by_extension(&path, b',');
+        assert_eq!(ext, "ssv");
+        assert_eq!(delim, b';');
+        assert!(snappy);
+    }
+
+    #[test]
+    fn test_snappy_case_insensitive() {
+        let path = PathBuf::from("test.csv.SZ");
+        let (ext, delim, snappy) = get_delim_by_extension(&path, b',');
+        assert_eq!(ext, "csv");
+        assert_eq!(delim, b',');
+        assert!(snappy);
+
+        let path = PathBuf::from("test.TSV.sz");
+        let (ext, delim, snappy) = get_delim_by_extension(&path, b',');
+        assert_eq!(ext, "tsv");
+        assert_eq!(delim, b'\t');
+        assert!(snappy);
+    }
 }
