@@ -74,7 +74,7 @@ fn sort_select() {
 
     let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
     let expected = vec![svec!["2", "a"], svec!["1", "b"]];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -103,7 +103,7 @@ fn sort_numeric() {
         svec!["2", "c"],
         svec!["10", "a"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -132,7 +132,7 @@ fn sort_numeric_faster() {
         svec!["2", "c"],
         svec!["10", "a"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -163,7 +163,7 @@ fn sort_numeric_non_natural() {
         svec!["7.4", "d"],
         svec!["8.33", "a"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -194,7 +194,7 @@ fn sort_numeric_non_natural_faster() {
         svec!["7.4", "d"],
         svec!["8.33", "a"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -224,7 +224,7 @@ fn sort_case_insensitive() {
         svec!["N", "S"],
         svec!["n", "S"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -254,7 +254,7 @@ fn sort_case_insensitive_faster() {
         svec!["N", "S"],
         svec!["n", "S"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -284,7 +284,7 @@ fn sort_case_sensitive() {
         svec!["n", "S"],
         svec!["n", "s"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -314,7 +314,7 @@ fn sort_case_sensitive_faster() {
         svec!["n", "S"],
         svec!["n", "s"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -330,7 +330,7 @@ fn sort_reverse() {
 
     let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
     let expected = vec![svec!["R", "S"], svec!["2", "a"], svec!["1", "b"]];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -349,7 +349,7 @@ fn sort_reverse_faster() {
 
     let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
     let expected = vec![svec!["R", "S"], svec!["2", "a"], svec!["1", "b"]];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -378,7 +378,7 @@ fn sort_uniq() {
         svec!["2", "c"],
         svec!["3", "f"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -411,7 +411,7 @@ fn sort_uniq_faster() {
         svec!["2", "c"],
         svec!["3", "f"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -443,7 +443,7 @@ fn sort_random() {
         svec!["2", "a"],
         svec!["6", "e"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -478,7 +478,7 @@ fn sort_random_faster() {
         svec!["5", "f"],
         svec!["3", "d"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
 }
 
 #[test]
@@ -513,7 +513,223 @@ fn sort_random_secure() {
         svec!["4", "c"],
         svec!["5", "f"],
     ];
-    similar_asserts::assert_eq!(got, expected);
+    assert_eq!(got, expected);
+}
+
+#[test]
+fn sort_natural() {
+    let wrk = Workdir::new("sort_natural");
+    wrk.create(
+        "in.csv",
+        vec![
+            svec!["Name", "Value"],
+            svec!["file2.txt", "a"],
+            svec!["file10.txt", "b"],
+            svec!["file1.txt", "c"],
+            svec!["file20.txt", "d"],
+            svec!["file3.txt", "e"],
+        ],
+    );
+
+    let mut cmd = wrk.command("sort");
+    cmd.arg("--natural").arg("in.csv");
+
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected = vec![
+        svec!["Name", "Value"],
+        svec!["file1.txt", "c"],
+        svec!["file2.txt", "a"],
+        svec!["file3.txt", "e"],
+        svec!["file10.txt", "b"],
+        svec!["file20.txt", "d"],
+    ];
+    assert_eq!(got, expected);
+}
+
+#[test]
+fn sort_natural_faster() {
+    let wrk = Workdir::new("sort_natural_faster");
+    wrk.create(
+        "in.csv",
+        vec![
+            svec!["Name", "Value"],
+            svec!["file2.txt", "a"],
+            svec!["file10.txt", "b"],
+            svec!["file1.txt", "c"],
+            svec!["file20.txt", "d"],
+            svec!["file3.txt", "e"],
+        ],
+    );
+
+    let mut cmd = wrk.command("sort");
+    cmd.arg("--natural").arg("--faster").arg("in.csv");
+
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected = vec![
+        svec!["Name", "Value"],
+        svec!["file1.txt", "c"],
+        svec!["file2.txt", "a"],
+        svec!["file3.txt", "e"],
+        svec!["file10.txt", "b"],
+        svec!["file20.txt", "d"],
+    ];
+    assert_eq!(got, expected);
+}
+
+#[test]
+fn sort_natural_case_insensitive() {
+    let wrk = Workdir::new("sort_natural_case_insensitive");
+    wrk.create(
+        "in.csv",
+        vec![
+            svec!["Name", "Value"],
+            svec!["File2.txt", "a"],
+            svec!["file10.txt", "b"],
+            svec!["FILE1.txt", "c"],
+            svec!["file20.txt", "d"],
+            svec!["File3.txt", "e"],
+        ],
+    );
+
+    let mut cmd = wrk.command("sort");
+    cmd.arg("--natural").arg("--ignore-case").arg("in.csv");
+
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected = vec![
+        svec!["Name", "Value"],
+        svec!["FILE1.txt", "c"],
+        svec!["File2.txt", "a"],
+        svec!["File3.txt", "e"],
+        svec!["file10.txt", "b"],
+        svec!["file20.txt", "d"],
+    ];
+    assert_eq!(got, expected);
+}
+
+#[test]
+fn sort_natural_reverse() {
+    let wrk = Workdir::new("sort_natural_reverse");
+    wrk.create(
+        "in.csv",
+        vec![
+            svec!["Name", "Value"],
+            svec!["file2.txt", "a"],
+            svec!["file10.txt", "b"],
+            svec!["file1.txt", "c"],
+            svec!["file20.txt", "d"],
+            svec!["file3.txt", "e"],
+        ],
+    );
+
+    let mut cmd = wrk.command("sort");
+    cmd.arg("--natural").arg("--reverse").arg("in.csv");
+
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected = vec![
+        svec!["Name", "Value"],
+        svec!["file20.txt", "d"],
+        svec!["file10.txt", "b"],
+        svec!["file3.txt", "e"],
+        svec!["file2.txt", "a"],
+        svec!["file1.txt", "c"],
+    ];
+    assert_eq!(got, expected);
+}
+
+#[test]
+fn sort_natural_mixed_content() {
+    let wrk = Workdir::new("sort_natural_mixed_content");
+    wrk.create(
+        "in.csv",
+        vec![
+            svec!["Name", "Value"],
+            svec!["chapter2", "a"],
+            svec!["chapter10", "b"],
+            svec!["chapter1", "c"],
+            svec!["appendix", "d"],
+            svec!["chapter3", "e"],
+            svec!["introduction", "f"],
+        ],
+    );
+
+    let mut cmd = wrk.command("sort");
+    cmd.arg("--natural").arg("in.csv");
+
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected = vec![
+        svec!["Name", "Value"],
+        svec!["appendix", "d"],
+        svec!["chapter1", "c"],
+        svec!["chapter2", "a"],
+        svec!["chapter3", "e"],
+        svec!["chapter10", "b"],
+        svec!["introduction", "f"],
+    ];
+    assert_eq!(got, expected);
+}
+
+#[test]
+fn sort_natural_vs_lexicographic() {
+    let wrk = Workdir::new("sort_natural_vs_lexicographic");
+    wrk.create(
+        "in.csv",
+        vec![
+            svec!["Name", "Value"],
+            svec!["file2.txt", "a"],
+            svec!["file10.txt", "b"],
+            svec!["file1.txt", "c"],
+        ],
+    );
+
+    // Test lexicographic sort (default)
+    let mut cmd = wrk.command("sort");
+    cmd.arg("in.csv");
+    let got_lex: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected_lex = vec![
+        svec!["Name", "Value"],
+        svec!["file1.txt", "c"],
+        svec!["file10.txt", "b"],
+        svec!["file2.txt", "a"],
+    ];
+    assert_eq!(got_lex, expected_lex);
+
+    // Test natural sort
+    let mut cmd = wrk.command("sort");
+    cmd.arg("--natural").arg("in.csv");
+    let got_nat: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected_nat = vec![
+        svec!["Name", "Value"],
+        svec!["file1.txt", "c"],
+        svec!["file2.txt", "a"],
+        svec!["file10.txt", "b"],
+    ];
+    assert_eq!(got_nat, expected_nat);
+}
+
+#[test]
+fn sort_natural_numeric_precedence() {
+    let wrk = Workdir::new("sort_natural_numeric_precedence");
+    wrk.create(
+        "in.csv",
+        vec![
+            svec!["Name", "Value"],
+            svec!["10", "a"],
+            svec!["2", "b"],
+            svec!["1", "c"],
+        ],
+    );
+
+    // Test that --natural takes precedence over --numeric
+    let mut cmd = wrk.command("sort");
+    cmd.arg("--natural").arg("--numeric").arg("in.csv");
+    let got: Vec<Vec<String>> = wrk.read_stdout(&mut cmd);
+    let expected = vec![
+        svec!["Name", "Value"],
+        svec!["1", "c"],
+        svec!["2", "b"],
+        svec!["10", "a"],
+    ];
+    assert_eq!(got, expected);
 }
 
 /// Order `a` and `b` lexicographically using `Ord`
